# hsi2rgb
Easily convert a hyperspectral image to an RGB image. hsi2rgb is a python package that supports numpy, torch and jax, with gamma correction, automatically convertions, XYZ and RGB colorspace suppots, etc.  
Please visit [hsi2rgb's github repo](https://github.com/songyz2019/hsi2rgb) for more information